Preprocessing
=============

Intensity
---------

.. currentmodule:: torchio.transforms.preprocessing.intensity

:class:`NormalizationTransform`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: NormalizationTransform
    :show-inheritance:


.. currentmodule:: torchio.transforms

:class:`Rescale`
~~~~~~~~~~~~~~~~

.. autoclass:: Rescale
    :show-inheritance:


:class:`ZNormalization`
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: ZNormalization
    :show-inheritance:


Spatial
-------

:class:`CenterCropOrPad`
~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: CenterCropOrPad
    :show-inheritance:


:class:`Crop`
~~~~~~~~~~~~~

.. autoclass:: Crop
    :show-inheritance:


:class:`Pad`
~~~~~~~~~~~~

.. autoclass:: Pad
    :show-inheritance:


:class:`Resample`
~~~~~~~~~~~~~~~~~

.. autoclass:: Resample
    :show-inheritance:


:class:`ToCanonical`
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: ToCanonical
    :show-inheritance:
